/*****************************************************************************
 * Stataload_NRD_2015Q4_DX_PR_GRPS.Do
 * Created on 10/31/2017.
 * This program will load the NRD_2015Q4_DX_PR_GRPS CSV File into Stata.
 * Because Stata loads the entire file into memory, it may not be possible
 * to load every data element for large files.  If necessary, edit this
 * program to change the memory size or to load only selected data elements.
 * The Stata INFILE command with the _SKIP option is used to select a subset of variables.
 * _skip (N) tells Stata to skip the next consecutive N variables.
 * Also can use "in" option after "using NRD_2015Q4_DX_PR_GRPS.csv" to read subset of the data.
 *****************************************************************************/

#delimit ;

/* Set available memory size */
set mem 1400m;

/* Read data elements from the csv file */
infile
      int    drg
      byte   drgver
      int    drg_nopoa
      byte   dxver
      long   hosp_nrd
      str7   i10_dx1
      str7   i10_dx2
      str7   i10_dx3
      str7   i10_dx4
      str7   i10_dx5
      str7   i10_dx6
      str7   i10_dx7
      str7   i10_dx8
      str7   i10_dx9
      str7   i10_dx10
      str7   i10_dx11
      str7   i10_dx12
      str7   i10_dx13
      str7   i10_dx14
      str7   i10_dx15
      str7   i10_dx16
      str7   i10_dx17
      str7   i10_dx18
      str7   i10_dx19
      str7   i10_dx20
      str7   i10_dx21
      str7   i10_dx22
      str7   i10_dx23
      str7   i10_dx24
      str7   i10_dx25
      str7   i10_dx26
      str7   i10_dx27
      str7   i10_dx28
      str7   i10_dx29
      str7   i10_dx30
      str7   i10_ecause1
      str7   i10_ecause2
      str7   i10_ecause3
      str7   i10_ecause4
      int    i10_ndx
      int    i10_necause
      int    i10_npr
      str7   i10_pr1
      str7   i10_pr2
      str7   i10_pr3
      str7   i10_pr4
      str7   i10_pr5
      str7   i10_pr6
      str7   i10_pr7
      str7   i10_pr8
      str7   i10_pr9
      str7   i10_pr10
      str7   i10_pr11
      str7   i10_pr12
      str7   i10_pr13
      str7   i10_pr14
      str7   i10_pr15
      double key_nrd
      byte   mdc
      byte   mdc_nopoa
      int    prday1
      int    prday2
      int    prday3
      int    prday4
      int    prday5
      int    prday6
      int    prday7
      int    prday8
      int    prday9
      int    prday10
      int    prday11
      int    prday12
      int    prday13
      int    prday14
      int    prday15
      byte   prver
using NRD_2015Q4_DX_PR_GRPS.csv;

/*  Assign labels to the data elements */
label var drg                      "DRG in effect on discharge date" ;
label var drgver                   "DRG grouper version used on discharge date" ;
label var drg_nopoa                "DRG in use on discharge date, calculated without POA" ;
label var dxver                    "Diagnosis Version" ;
label var hosp_nrd                 "NRD hospital identifier" ;
label var i10_dx1                  "ICD-10-CM Diagnosis 1" ;
label var i10_dx2                  "ICD-10-CM Diagnosis 2" ;
label var i10_dx3                  "ICD-10-CM Diagnosis 3" ;
label var i10_dx4                  "ICD-10-CM Diagnosis 4" ;
label var i10_dx5                  "ICD-10-CM Diagnosis 5" ;
label var i10_dx6                  "ICD-10-CM Diagnosis 6" ;
label var i10_dx7                  "ICD-10-CM Diagnosis 7" ;
label var i10_dx8                  "ICD-10-CM Diagnosis 8" ;
label var i10_dx9                  "ICD-10-CM Diagnosis 9" ;
label var i10_dx10                 "ICD-10-CM Diagnosis 10" ;
label var i10_dx11                 "ICD-10-CM Diagnosis 11" ;
label var i10_dx12                 "ICD-10-CM Diagnosis 12" ;
label var i10_dx13                 "ICD-10-CM Diagnosis 13" ;
label var i10_dx14                 "ICD-10-CM Diagnosis 14" ;
label var i10_dx15                 "ICD-10-CM Diagnosis 15" ;
label var i10_dx16                 "ICD-10-CM Diagnosis 16" ;
label var i10_dx17                 "ICD-10-CM Diagnosis 17" ;
label var i10_dx18                 "ICD-10-CM Diagnosis 18" ;
label var i10_dx19                 "ICD-10-CM Diagnosis 19" ;
label var i10_dx20                 "ICD-10-CM Diagnosis 20" ;
label var i10_dx21                 "ICD-10-CM Diagnosis 21" ;
label var i10_dx22                 "ICD-10-CM Diagnosis 22" ;
label var i10_dx23                 "ICD-10-CM Diagnosis 23" ;
label var i10_dx24                 "ICD-10-CM Diagnosis 24" ;
label var i10_dx25                 "ICD-10-CM Diagnosis 25" ;
label var i10_dx26                 "ICD-10-CM Diagnosis 26" ;
label var i10_dx27                 "ICD-10-CM Diagnosis 27" ;
label var i10_dx28                 "ICD-10-CM Diagnosis 28" ;
label var i10_dx29                 "ICD-10-CM Diagnosis 29" ;
label var i10_dx30                 "ICD-10-CM Diagnosis 30" ;
label var i10_ecause1              "ICD-10-CM External cause 1" ;
label var i10_ecause2              "ICD-10-CM External cause 2" ;
label var i10_ecause3              "ICD-10-CM External cause 3" ;
label var i10_ecause4              "ICD-10-CM External cause 4" ;
label var i10_ndx                  "ICD-10-CM Number of diagnoses on this record" ;
label var i10_necause              "ICD-10-CM Number of external cause codes on this record" ;
label var i10_npr                  "ICD-10-PCS Number of procedures on this record" ;
label var i10_pr1                  "ICD-10-PCS Procedure 1" ;
label var i10_pr2                  "ICD-10-PCS Procedure 2" ;
label var i10_pr3                  "ICD-10-PCS Procedure 3" ;
label var i10_pr4                  "ICD-10-PCS Procedure 4" ;
label var i10_pr5                  "ICD-10-PCS Procedure 5" ;
label var i10_pr6                  "ICD-10-PCS Procedure 6" ;
label var i10_pr7                  "ICD-10-PCS Procedure 7" ;
label var i10_pr8                  "ICD-10-PCS Procedure 8" ;
label var i10_pr9                  "ICD-10-PCS Procedure 9" ;
label var i10_pr10                 "ICD-10-PCS Procedure 10" ;
label var i10_pr11                 "ICD-10-PCS Procedure 11" ;
label var i10_pr12                 "ICD-10-PCS Procedure 12" ;
label var i10_pr13                 "ICD-10-PCS Procedure 13" ;
label var i10_pr14                 "ICD-10-PCS Procedure 14" ;
label var i10_pr15                 "ICD-10-PCS Procedure 15" ;
label var key_nrd                  "NRD record identifier" ;
label var mdc                      "MDC in effect on discharge date" ;
label var mdc_nopoa                "MDC in use on discharge date, calculated without POA" ;
label var prday1                   "Number of days from admission to I10_PR1" ;
label var prday2                   "Number of days from admission to I10_PR2" ;
label var prday3                   "Number of days from admission to I10_PR3" ;
label var prday4                   "Number of days from admission to I10_PR4" ;
label var prday5                   "Number of days from admission to I10_PR5" ;
label var prday6                   "Number of days from admission to I10_PR6" ;
label var prday7                   "Number of days from admission to I10_PR7" ;
label var prday8                   "Number of days from admission to I10_PR8" ;
label var prday9                   "Number of days from admission to I10_PR9" ;
label var prday10                  "Number of days from admission to I10_PR10" ;
label var prday11                  "Number of days from admission to I10_PR11" ;
label var prday12                  "Number of days from admission to I10_PR12" ;
label var prday13                  "Number of days from admission to I10_PR13" ;
label var prday14                  "Number of days from admission to I10_PR14" ;
label var prday15                  "Number of days from admission to I10_PR15" ;
label var prver                    "Procedure Version" ;

/* Convert special values to missing values */
recode drg                       (-99 -88 -66=.) ;
recode drgver                    (-9 -8 -6 -5=.) ;
recode drg_nopoa                 (-99 -88 -66=.) ;
recode dxver                     (-9 -8 -6 -5=.) ;
recode hosp_nrd                  (-9999 -8888 -6666=.) ;
recode i10_ndx                   (-99 -88 -66=.) ;
recode i10_necause               (-99 -88 -66=.) ;
recode i10_npr                   (-99 -88 -66=.) ;
recode key_nrd                   (-99999999999999 -88888888888888 -66666666666666=.) ;
recode mdc                       (-9 -8 -6 -5=.) ;
recode mdc_nopoa                 (-9 -8 -6 -5=.) ;
recode prday1                    (-99 -88 -66=.) ;
recode prday2                    (-99 -88 -66=.) ;
recode prday3                    (-99 -88 -66=.) ;
recode prday4                    (-99 -88 -66=.) ;
recode prday5                    (-99 -88 -66=.) ;
recode prday6                    (-99 -88 -66=.) ;
recode prday7                    (-99 -88 -66=.) ;
recode prday8                    (-99 -88 -66=.) ;
recode prday9                    (-99 -88 -66=.) ;
recode prday10                   (-99 -88 -66=.) ;
recode prday11                   (-99 -88 -66=.) ;
recode prday12                   (-99 -88 -66=.) ;
recode prday13                   (-99 -88 -66=.) ;
recode prday14                   (-99 -88 -66=.) ;
recode prday15                   (-99 -88 -66=.) ;
recode prver                     (-9 -8 -6 -5=.) ;

describe;

save "NRD_2015Q4_DX_PR_GRPS.dta", replace;
#delimit cr
